---
title: 영중소 수수료율은 무엇인가요?
category: 자주 묻는 질문 (일반 문의) > 일반 문의 > 자주 묻는 질문
seo:
  title: 영중소 수수료율은 무엇인가요?
  description: >-
    정부 정책에 의해 매출규모에 따라 영세, 중소 사업자에 대한 우대 수수료율이 적용되며, 포트원은 해당 영중소 수수료율의 기준을 따르고
    있습니다. 지금 상세 정보를 확인해보세요.
  keywords:
    - PG사 요금
tags:
  - 공통
  - PG사 요금
pgCompanies:
  - 공통
searchTags:
  - 일반사업자
  - 중소
  - 영세
  - 영중소수수료율
  - 수수료율
  - 영중소
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="포트원에서 안내드리는 수수료율 중 '영중소 수수료율'의 개념과 그 기준을 안내드립니다." />

#### **영중소 수수료율이란?**

PG사 수수료율은 2019년 1월 31일부터 정부 정책에 의해 매출규모에 따라 영세, 중소 사업자에 대한 우대 수수료율이 적용됩니다.

- 적용시점 : 매년 반기별(1월/7월) 적용
- 적용방법 : 국세청으로부터 영세/중소 신용카드 사업장들의 사업자 명단을 PG사로 전달하고, PG사에서는 해당 매출액을 기준으로 수수료율 자동적용 (PG사별 어드민 페이지 및 공지사항 참조)
- 참고 : 신규서비스(매출이 발생되지 않은 사업자)는 첫 세금 신고 전까지 '일반사업자'로 적용됩니다.

<Callout content="- 영세 사업자 : ~ 3억원 미만
- 중소1 사업자 : 3억원 ~ 5억원 미만
- 중소2 사업자 : 5억원 ~ 10억원 미만
- 중소3 사업자 : 10억원 ~ 30억원 미만
- 일반 사업자 : 30억원 초과
" title="영중소 구분 : 연 매출액 기준" icon="💡" />
